# Config system and history example

This project is a use case example to learn how to setup and use the config
and the config history to perform and monitor experiments.

Run main.py, then read it while looking at the results in the project folder.
The stuff in project_utils is project-agnostic and does not need to be read
to understand what's happening.

You will need Python 3.7+ with `pygraphviz` 1.7 as well as `scipy` and
`numpy`, and `graphviz` installed on your machine.
